@@ -1,4 +1,4 @@
-# Copyright 2016-2017 IBM Corp. All Rights Reserved.
+# Copyright 2016-2021 IBM Corp. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -61,6 +61,7 @@ from ._virtual_switch import VirtualSwitchManager
 from ._capacity_group import CapacityGroupManager
 from ._logging import logged_api_call
 from ._exceptions import ParseError
+from ._utils import matches_filters, divide_filter_args
 
 __all__ = ['CpcManager', 'Cpc']
 
@@ -173,7 +174,8 @@ class CpcManager(BaseManager):
             resource_obj_list.append(resource_obj)
             # It already has full properties
         else:
-            query_parms, client_filters = self._divide_filter_args(filter_args)
+            query_parms, client_filters = divide_filter_args(
+                self._query_props, filter_args)
 
             resources_name = 'cpcs'
             uri = '/api/{}{}'.format(resources_name, query_parms)
@@ -189,7 +191,7 @@ class CpcManager(BaseManager):
                         name=props.get(self._name_prop, None),
                         properties=props)
 
-                    if self._matches_filters(resource_obj, client_filters):
+                    if matches_filters(resource_obj, client_filters):
                         resource_obj_list.append(resource_obj)
                         if full_properties:
                             resource_obj.pull_full_properties()
@@ -536,6 +538,9 @@ class Cpc(BaseResource):
         """
         Update writeable properties of this CPC.
 
+        This method serializes with other methods that access or change
+        properties on the same Python object.
+
         Authorization requirements:
 
         * Object-access permission to this CPC.
@@ -560,7 +565,7 @@ class Cpc(BaseResource):
         # Attempts to change the 'name' property will be rejected by the HMC,
         # so we don't need to update the name-to-URI cache.
         assert self.manager._name_prop not in properties
-        self._properties.update(copy.deepcopy(properties))
+        self.update_properties_local(copy.deepcopy(properties))
 
     @logged_api_call
     def start(self, wait_for_completion=True, operation_timeout=None):
