@@ -1,4 +1,4 @@
-# Copyright 2016-2017 IBM Corp. All Rights Reserved.
+# Copyright 2016-2021 IBM Corp. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -34,6 +34,7 @@ from ._manager import BaseManager
 from ._resource import BaseResource
 from ._exceptions import StatusTimeout
 from ._logging import logged_api_call
+from ._utils import matches_filters, divide_filter_args
 
 __all__ = ['LparManager', 'Lpar']
 
@@ -128,7 +129,8 @@ class LparManager(BaseManager):
             resource_obj_list.append(resource_obj)
             # It already has full properties
         else:
-            query_parms, client_filters = self._divide_filter_args(filter_args)
+            query_parms, client_filters = divide_filter_args(
+                self._query_props, filter_args)
 
             resources_name = 'logical-partitions'
             uri = '{}/{}{}'.format(self.cpc.uri, resources_name, query_parms)
@@ -144,7 +146,7 @@ class LparManager(BaseManager):
                         name=props.get(self._name_prop, None),
                         properties=props)
 
-                    if self._matches_filters(resource_obj, client_filters):
+                    if matches_filters(resource_obj, client_filters):
                         resource_obj_list.append(resource_obj)
                         if full_properties:
                             resource_obj.pull_full_properties()
@@ -186,13 +188,25 @@ class Lpar(BaseResource):
         """
         Update writeable properties of this LPAR.
 
+        This method serializes with other methods that access or change
+        properties on the same Python object.
+
         Authorization requirements:
 
         * Object-access permission to this LPAR.
+        * Before HMC API version 3.6 in an update to HMC 2.15.0: Object-access
+          permission to the CPC of this LPAR.
         * Task permission for the "Change Object Definition" task.
-        * Object-access permission to the CPC of this LPAR.
-        * For an LPAR whose activation-mode is "zaware", task permission for
-          the "Firmware Details" task.
+        * Since HMC 2.14.1: If the "next-activation-profile-name" property is to
+          be updated, task permission for the "Change Object Options" task or
+          the "Customize/Delete Activation Profiles" task.
+        * Before HMC 2.15.0: For an LPAR whose activation-mode is "zaware", task
+          permission for the "Firmware Details" task.
+        * Since HMC 2.15.0: If any of the "ssc-*" or "zaware-*" properties is to
+          be updated, task permission for the "Firmware Details" task.
+        * Since HMC 2.15.0: If any of the numbers of allocated or reserved cores
+          is to be updated, task permission for the "Logical Processor Add"
+          task.
 
         Parameters:
 
@@ -214,7 +228,7 @@ class Lpar(BaseResource):
         # Attempts to change the 'name' property will be rejected by the HMC,
         # so we don't need to update the name-to-URI cache.
         assert self.manager._name_prop not in properties
-        self._properties.update(copy.deepcopy(properties))
+        self.update_properties_local(copy.deepcopy(properties))
 
     @logged_api_call
     def activate(self, wait_for_completion=True,
@@ -237,8 +251,9 @@ class Lpar(BaseResource):
 
         Authorization requirements:
 
-        * Object-access permission to the CPC containing this LPAR.
         * Object-access permission to this LPAR.
+        * Before HMC API version 3.6 in an update to HMC 2.15.0: Object-access
+          permission to the CPC of this LPAR.
         * Task permission for the "Activate" task.
 
         Parameters:
@@ -345,8 +360,9 @@ class Lpar(BaseResource):
 
         Authorization requirements:
 
-        * Object-access permission to the CPC containing this LPAR.
         * Object-access permission to this LPAR.
+        * Before HMC API version 3.6 in an update to HMC 2.15.0: Object-access
+          permission to the CPC of this LPAR.
         * Task permission for the "Deactivate" task.
 
         Parameters:
@@ -450,8 +466,9 @@ class Lpar(BaseResource):
 
         Authorization requirements:
 
-        * Object-access permission to the CPC containing this LPAR.
         * Object-access permission to this LPAR.
+        * Before HMC API version 3.6 in an update to HMC 2.15.0: Object-access
+          permission to the CPC of this LPAR.
         * Task permission for the "SCSI Load" task.
 
         Parameters:
@@ -600,8 +617,9 @@ class Lpar(BaseResource):
 
         Authorization requirements:
 
-        * Object-access permission to the CPC containing this LPAR.
         * Object-access permission to this LPAR.
+        * Before HMC API version 3.6 in an update to HMC 2.15.0: Object-access
+          permission to the CPC of this LPAR.
         * Task permission for the "SCSI Dump" task.
 
         Parameters:
@@ -745,8 +763,9 @@ class Lpar(BaseResource):
 
         Authorization requirements:
 
-        * Object-access permission to the CPC containing this LPAR.
         * Object-access permission to this LPAR.
+        * Before HMC API version 3.6 in an update to HMC 2.15.0: Object-access
+          permission to the CPC of this LPAR.
         * Task permission for the "Load" task.
 
         Parameters:
@@ -871,8 +890,9 @@ class Lpar(BaseResource):
 
         Authorization requirements:
 
-        * Object-access permission to the CPC containing this LPAR.
         * Object-access permission to this LPAR.
+        * Before HMC API version 3.6 in an update to HMC 2.15.0: Object-access
+          permission to the CPC of this LPAR.
         * Task permission for the "Stop" task.
 
         Parameters:
@@ -963,8 +983,9 @@ class Lpar(BaseResource):
 
         Authorization requirements:
 
-        * Object-access permission to the CPC containing this LPAR.
         * Object-access permission to this LPAR.
+        * Before HMC API version 3.6 in an update to HMC 2.15.0: Object-access
+          permission to the CPC of this LPAR.
         * Task permission for the "Reset Clear" task.
 
         Parameters:
@@ -1048,6 +1069,12 @@ class Lpar(BaseResource):
         Open a JMS message channel to this LPAR's operating system, returning
         the string "topic" representing the message channel.
 
+        Authorization requirements:
+
+        * Object-access permission to this Partition.
+        * Task permission to the "Operating System Messages" task at least
+          in view-only mode.
+
         Parameters:
 
           include_refresh_messages (bool):
@@ -1085,6 +1112,12 @@ class Lpar(BaseResource):
         """
         Send a command to the operating system running in this LPAR.
 
+        Authorization requirements:
+
+        * Object-access permission to this Partition.
+        * Task permission to the "Operating System Messages" task in
+          modification mode.
+
         Parameters:
 
           os_command_text (string): The text of the operating system command.
@@ -1131,8 +1164,9 @@ class Lpar(BaseResource):
 
         Authorization requirements:
 
-        * Object-access permission to the CPC containing this LPAR.
         * Object-access permission to this LPAR.
+        * Before HMC API version 3.6 in an update to HMC 2.15.0: Object-access
+          permission to the CPC of this LPAR.
         * Task permission for the "PSW Restart" task.
 
         Parameters:
