@@ -1,4 +1,4 @@
-# Copyright 2016-2017 IBM Corp. All Rights Reserved.
+# Copyright 2016-2021 IBM Corp. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -34,7 +34,7 @@ import six
 
 from ._logging import logged_api_call
 from ._exceptions import NotFound, NoUniqueMatch, HTTPError
-from ._utils import repr_list, append_query_parms
+from ._utils import repr_list
 
 __all__ = ['BaseManager']
 
@@ -383,140 +383,6 @@ class BaseManager(object):
 
         return resource_obj
 
-    def _divide_filter_args(self, filter_args):
-        """
-        Divide the filter arguments into filter query parameters for filtering
-        on the server side, and the remaining client-side filters.
-
-        Parameters:
-
-          filter_args (dict):
-            Filter arguments that narrow the list of returned resources to
-            those that match the specified filter arguments. For details, see
-            :ref:`Filtering`.
-
-            `None` causes no filtering to happen, i.e. all resources are
-            returned.
-
-        Returns:
-
-          : tuple (query_parms_str, client_filter_args)
-        """
-        query_parms = []  # query parameter strings
-        client_filter_args = {}
-
-        if filter_args is not None:
-            for prop_name in filter_args:
-                prop_match = filter_args[prop_name]
-                if prop_name in self._query_props:
-                    append_query_parms(query_parms, prop_name, prop_match)
-                else:
-                    client_filter_args[prop_name] = prop_match
-        query_parms_str = '&'.join(query_parms)
-        if query_parms_str:
-            query_parms_str = '?{}'.format(query_parms_str)
-
-        return query_parms_str, client_filter_args
-
-    def _matches_filters(self, obj, filter_args):
-        """
-        Return a boolean indicating whether a resource object matches a set
-        of filter arguments.
-        This is used for client-side filtering.
-
-        Depending on the properties specified in the filter arguments, this
-        method retrieves the resource properties from the HMC.
-
-        Parameters:
-
-          obj (BaseResource):
-            Resource object.
-
-          filter_args (dict):
-            Filter arguments. For details, see :ref:`Filtering`.
-            `None` causes the resource to always match.
-
-        Returns:
-
-          bool: Boolean indicating whether the resource object matches the
-            filter arguments.
-        """
-        if filter_args is not None:
-            for prop_name in filter_args:
-                prop_match = filter_args[prop_name]
-                if not self._matches_prop(obj, prop_name, prop_match):
-                    return False
-        return True
-
-    def _matches_prop(self, obj, prop_name, prop_match):
-        """
-        Return a boolean indicating whether a resource object matches with
-        a single property against a property match value.
-        This is used for client-side filtering.
-
-        Depending on the specified property, this method retrieves the resource
-        properties from the HMC.
-
-        Parameters:
-
-          obj (BaseResource):
-            Resource object.
-
-          prop_match:
-            Property match value that is used to match the actual value of
-            the specified property against, as follows:
-
-            - If the match value is a list or tuple, this method is invoked
-              recursively to find whether one or more match values inthe list
-              match.
-
-            - Else if the property is of string type, its value is matched by
-              interpreting the match value as a regular expression.
-
-            - Else the property value is matched by exact value comparison
-              with the match value.
-
-        Returns:
-
-          bool: Boolean indicating whether the resource object matches w.r.t.
-            the specified property and the match value.
-        """
-        if isinstance(prop_match, (list, tuple)):
-            # List items are logically ORed, so one matching item suffices.
-            for pm in prop_match:
-                if self._matches_prop(obj, prop_name, pm):
-                    return True
-        else:
-            # Some lists of resources do not have all properties, for example
-            # Hipersocket adapters do not have a "card-location" property.
-            # If a filter property does not exist on a resource, the resource
-            # does not match.
-            try:
-                prop_value = obj.get_property(prop_name)
-            except KeyError:
-                return False
-            if isinstance(prop_value, six.string_types):
-                # HMC resource property is Enum String or (non-enum) String,
-                # and is both matched by regexp matching. Ideally, regexp
-                # matching should only be done for non-enum strings, but
-                # distinguishing them is not possible given that the client
-                # has no knowledge about the properties.
-
-                # The regexp matching implemented in the HMC requires begin and
-                # end of the string value to match, even if the '^' for begin
-                # and '$' for end are not specified in the pattern. The code
-                # here is consistent with that: We add end matching to the
-                # pattern, and begin matching is done by re.match()
-                # automatically.
-                re_match = prop_match + '$'
-                m = re.match(re_match, prop_value)
-                if m:
-                    return True
-            else:
-                if prop_value == prop_match:
-                    return True
-        return False
-
     @property
     def resource_class(self):
         """
@@ -588,15 +454,19 @@ class BaseManager(object):
             assert uri_or_oid[-1] != '/'
             uri = uri_or_oid
             oid = uri.split('/')[-1]
+            # For the Console, we can predict the URI but not the OID.
+            if oid == 'console':
+                oid = None
         else:
             assert '/' not in uri_or_oid
             oid = uri_or_oid
             uri = '{}/{}'.format(self._base_uri, oid)
         res_props = {
-            self._oid_prop: oid,
             'parent': self.parent.uri if self.parent is not None else None,
             'class': self.class_name,
         }
+        if oid:
+            res_props[self._oid_prop] = oid
         name = None
         if props:
             res_props.update(props)
@@ -878,6 +748,54 @@ class BaseManager(object):
             properties=None)
         return obj
 
+    @logged_api_call
+    def find_local(self, name, uri, properties=None):
+        """
+        Return a local resource object without fetching it from the HMC.
+
+        The resource object is fully functional, for example it has the proper
+        parent resource object set and its properties can be fetched using
+        :meth:`~zhmcclient.BaseResource.pull_full_properties`.
+
+        If the resource object is in the name-to-URI cache, it is returned from
+        there, and dependent on the history it may have a minimal set of
+        properties or the full set of properties. Otherwise, a new resource
+        object is constructed locally from the specified name, uri and
+        properties parameters. That resource object is not put into the
+        name-to-URI cache because there was no validation that the specified
+        properties are up to date or even valid at all.
+
+        Parameters:
+
+          name (string):
+            Name of the resource. Must not be `None`.
+
+          uri (string):
+            Object URI of the resource. Must not be `None`.
+
+          properties (dict):
+            Additional properties. Only used when the resource is not found
+            in the name-to-URI cache. It is the responsibility of the user
+            to ensure that the properties are valid.
+
+        Returns:
+
+          Resource object.
+        """
+        # Get the resource object from the name-to-URI cache, if possible.
+        resource_obj = self._try_optimized_lookup(dict(name=name))
+        if resource_obj:
+            assert uri == resource_obj.uri
+            return resource_obj
+
+        # Create a new local resource object.
+        resource_props = {
+            self._name_prop: name,
+        }
+        resource_props.update(properties)
+        resource_obj = self.resource_object(uri, resource_props)
+        return resource_obj
+
     @logged_api_call
     def flush(self):
         """
