@@ -1,4 +1,4 @@
-# Copyright 2016-2017 IBM Corp. All Rights Reserved.
+# Copyright 2016-2021 IBM Corp. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -42,6 +42,7 @@ from ._nic import NicManager
 from ._hba import HbaManager
 from ._virtual_function import VirtualFunctionManager
 from ._logging import logged_api_call
+from ._utils import matches_filters, divide_filter_args
 
 __all__ = ['PartitionManager', 'Partition']
 
@@ -140,7 +141,8 @@ class PartitionManager(BaseManager):
             resource_obj_list.append(resource_obj)
             # It already has full properties
         else:
-            query_parms, client_filters = self._divide_filter_args(filter_args)
+            query_parms, client_filters = divide_filter_args(
+                self._query_props, filter_args)
 
             resources_name = 'partitions'
             uri = '{}/{}{}'.format(self.cpc.uri, resources_name, query_parms)
@@ -156,7 +158,7 @@ class PartitionManager(BaseManager):
                         name=props.get(self._name_prop, None),
                         properties=props)
 
-                    if self._matches_filters(resource_obj, client_filters):
+                    if matches_filters(resource_obj, client_filters):
                         resource_obj_list.append(resource_obj)
                         if full_properties:
                             resource_obj.pull_full_properties()
@@ -386,7 +388,6 @@ class Partition(BaseResource):
         Authorization requirements:
 
         * Object-access permission to this Partition.
-        * Object-access permission to the CPC containing this Partition.
         * Task permission to the "Start Partition" task.
 
         Parameters:
@@ -541,13 +542,16 @@ class Partition(BaseResource):
         # pylint: disable=protected-access
         self.manager.session.delete(self.uri)
         self.manager._name_uri_cache.delete(
-            self._properties.get(self.manager._name_prop, None))
+            self.get_properties_local(self.manager._name_prop, None))
 
     @logged_api_call
     def update_properties(self, properties):
         """
         Update writeable properties of this Partition.
 
+        This method serializes with other methods that access or change
+        properties on the same Python object.
+
         Authorization requirements:
 
         * Object-access permission to this Partition.
@@ -574,7 +578,7 @@ class Partition(BaseResource):
         if is_rename:
             # Delete the old name from the cache
             self.manager._name_uri_cache.delete(self.name)
-        self._properties.update(copy.deepcopy(properties))
+        self.update_properties_local(copy.deepcopy(properties))
         if is_rename:
             # Add the new name to the cache
             self.manager._name_uri_cache.update(self.name, self.uri)
@@ -588,7 +592,7 @@ class Partition(BaseResource):
         'Dump Partition'.
 
         This operation requires that the CPC does not have the storage
-        management feature (i.e. is a z13 or earlier).
+        management feature (i.e. is a z13).
 
         Authorization requirements:
 
@@ -851,6 +855,12 @@ class Partition(BaseResource):
         Open a JMS message channel to this partition's operating system,
         returning the string "topic" representing the message channel.
 
+        Authorization requirements:
+
+        * Object-access permission to this Partition.
+        * Task permission to the "Operating System Messages" task at least
+          in view-only mode.
+
         Parameters:
 
           include_refresh_messages (bool):
@@ -888,6 +898,12 @@ class Partition(BaseResource):
         """
         Send a command to the operating system running in this partition.
 
+        Authorization requirements:
+
+        * Object-access permission to this Partition.
+        * Task permission to the "Operating System Messages" task in
+          modification mode.
+
         Parameters:
 
           os_command_text (string): The text of the operating system command.
@@ -1000,6 +1016,7 @@ class Partition(BaseResource):
         Authorization requirements:
 
         * Object-access permission to this Partition.
+        * Object-access permission to the specified Crypto Adapter.
         * Task permission to the "Partition Details" task.
 
         Parameters:
@@ -1070,6 +1087,7 @@ class Partition(BaseResource):
         Authorization requirements:
 
         * Object-access permission to this Partition.
+        * Object-access permission to the specified Crypto Adapters.
         * Task permission to the "Partition Details" task.
 
         Parameters:
@@ -1152,7 +1170,8 @@ class Partition(BaseResource):
 
         Authorization requirements:
 
-        * Object-access permission to this Partition and to the Crypto Adapter.
+        * Object-access permission to this Partition.
+        * Object-access permission to the specified Crypto Adapter.
         * Task permission to the "Zeroize Crypto Domain" task.
 
         Parameters:
@@ -1264,7 +1283,6 @@ class Partition(BaseResource):
         Authorization requirements:
 
         * Object-access permission to this partition.
-        * Task permission to the "Partition Details" task.
 
         Parameters:
 
