@@ -1,4 +1,4 @@
-# Copyright 2018 IBM Corp. All Rights Reserved.
+# Copyright 2018-2021 IBM Corp. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -88,7 +88,7 @@ from ._resource import BaseResource
 from ._storage_volume import StorageVolumeManager
 from ._virtual_storage_resource import VirtualStorageResourceManager
 from ._logging import logged_api_call
-from ._utils import append_query_parms
+from ._utils import append_query_parms, matches_filters, divide_filter_args
 
 __all__ = ['StorageGroupManager', 'StorageGroup']
 
@@ -194,7 +194,8 @@ class StorageGroupManager(BaseManager):
             resource_obj_list.append(resource_obj)
             # It already has full properties
         else:
-            query_parms, client_filters = self._divide_filter_args(filter_args)
+            query_parms, client_filters = divide_filter_args(
+                self._query_props, filter_args)
             uri = '{}{}'.format(self._base_uri, query_parms)
 
             result = self.session.get(uri)
@@ -208,7 +209,7 @@ class StorageGroupManager(BaseManager):
                         name=props.get(self._name_prop, None),
                         properties=props)
 
-                    if self._matches_filters(resource_obj, client_filters):
+                    if matches_filters(resource_obj, client_filters):
                         resource_obj_list.append(resource_obj)
                         if full_properties:
                             resource_obj.pull_full_properties()
@@ -495,7 +496,7 @@ class StorageGroup(BaseResource):
 
         # pylint: disable=protected-access
         self.manager._name_uri_cache.delete(
-            self._properties.get(self.manager._name_prop, None))
+            self.get_properties_local(self.manager._name_prop, None))
 
     @logged_api_call
     def update_properties(self, properties):
@@ -510,6 +511,9 @@ class StorageGroup(BaseResource):
         created, deleted and updated using the respective methods on
         :attr:`~zhmcclient.StorageGroup.storage_volumes`.
 
+        This method serializes with other methods that access or change
+        properties on the same Python object.
+
         Authorization requirements:
 
         * Object-access permission to this storage group.
@@ -538,7 +542,7 @@ class StorageGroup(BaseResource):
         if is_rename:
             # Delete the old name from the cache
             self.manager._name_uri_cache.delete(self.name)
-        self._properties.update(copy.deepcopy(properties))
+        self.update_properties_local(copy.deepcopy(properties))
         if is_rename:
             # Add the new name to the cache
             self.manager._name_uri_cache.update(self.name, self.uri)
