@@ -1,4 +1,4 @@
-# Copyright 2018 IBM Corp. All Rights Reserved.
+# Copyright 2018-2021 IBM Corp. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -45,6 +45,7 @@ import copy
 from ._manager import BaseManager
 from ._resource import BaseResource
 from ._logging import logged_api_call
+from ._utils import matches_filters, divide_filter_args
 
 __all__ = ['StorageVolumeManager', 'StorageVolume']
 
@@ -145,7 +146,8 @@ class StorageVolumeManager(BaseManager):
             resource_obj_list.append(resource_obj)
             # It already has full properties
         else:
-            query_parms, client_filters = self._divide_filter_args(filter_args)
+            query_parms, client_filters = divide_filter_args(
+                self._query_props, filter_args)
 
             resources_name = 'storage-volumes'
             uri = '{}/{}{}'.format(self.storage_group.uri, resources_name,
@@ -162,7 +164,7 @@ class StorageVolumeManager(BaseManager):
                         name=props.get(self._name_prop, None),
                         properties=props)
 
-                    if self._matches_filters(resource_obj, client_filters):
+                    if matches_filters(resource_obj, client_filters):
                         resource_obj_list.append(resource_obj)
                         if full_properties:
                             resource_obj.pull_full_properties()
@@ -406,7 +408,7 @@ class StorageVolume(BaseResource):
 
         # pylint: disable=protected-access
         self.manager._name_uri_cache.delete(
-            self._properties.get(self.manager._name_prop, None))
+            self.get_properties_local(self.manager._name_prop, None))
 
     @logged_api_call
     def update_properties(self, properties, email_to_addresses=None,
@@ -420,6 +422,9 @@ class StorageVolume(BaseResource):
         This method performs the "Modify Storage Group Properties" operation,
         requesting modification of the volume.
 
+        This method serializes with other methods that access or change
+        properties on the same Python object.
+
         Authorization requirements:
 
         * Object-access permission to the storage group owning this storage
@@ -491,7 +496,7 @@ class StorageVolume(BaseResource):
             self.manager.storage_group.uri + '/operations/modify',
             body=body)
 
-        self._properties.update(copy.deepcopy(properties))
+        self.update_properties_local(copy.deepcopy(properties))
 
     @logged_api_call
     def indicate_fulfillment_ficon(self, control_unit, unit_address):
