@@ -1,4 +1,4 @@
-# Copyright 2019 IBM Corp. All Rights Reserved.
+# Copyright 2019-2021 IBM Corp. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -40,6 +40,7 @@ import copy
 from ._manager import BaseManager
 from ._resource import BaseResource
 from ._logging import logged_api_call
+from ._utils import matches_filters, divide_filter_args
 
 __all__ = ['StorageVolumeTemplateManager', 'StorageVolumeTemplate']
 
@@ -140,7 +141,8 @@ class StorageVolumeTemplateManager(BaseManager):
             resource_obj_list.append(resource_obj)
             # It already has full properties
         else:
-            query_parms, client_filters = self._divide_filter_args(filter_args)
+            query_parms, client_filters = divide_filter_args(
+                self._query_props, filter_args)
 
             resources_name = 'storage-template-volumes'
             uri = '{}/{}{}'.format(self.storage_group_template.uri,
@@ -157,7 +159,7 @@ class StorageVolumeTemplateManager(BaseManager):
                         name=props.get(self._name_prop, None),
                         properties=props)
 
-                    if self._matches_filters(resource_obj, client_filters):
+                    if matches_filters(resource_obj, client_filters):
                         resource_obj_list.append(resource_obj)
                         if full_properties:
                             resource_obj.pull_full_properties()
@@ -305,7 +307,7 @@ class StorageVolumeTemplate(BaseResource):
 
         # pylint: disable=protected-access
         self.manager._name_uri_cache.delete(
-            self._properties.get(self.manager._name_prop, None))
+            self.get_properties_local(self.manager._name_prop, None))
 
     @logged_api_call
     def update_properties(self, properties):
@@ -315,6 +317,9 @@ class StorageVolumeTemplate(BaseResource):
         This method performs the "Modify Storage Template Properties"
         operation, requesting modification of the volume.
 
+        This method serializes with other methods that access or change
+        properties on the same Python object.
+
         Authorization requirements:
 
         * Object-access permission to the storage group template owning this
@@ -352,4 +357,4 @@ class StorageVolumeTemplate(BaseResource):
         self.manager.session.post(
             self.manager.storage_group_template.uri + '/operations/modify',
             body=body)
-        self._properties.update(copy.deepcopy(properties))
+        self.update_properties_local(copy.deepcopy(properties))
