@@ -1,4 +1,4 @@
-# Copyright 2017 IBM Corp. All Rights Reserved.
+# Copyright 2017-2021 IBM Corp. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -37,6 +37,7 @@ import copy
 from ._manager import BaseManager
 from ._resource import BaseResource
 from ._logging import logged_api_call
+from ._utils import matches_filters, divide_filter_args
 
 __all__ = ['UserPatternManager', 'UserPattern']
 
@@ -127,7 +128,8 @@ class UserPatternManager(BaseManager):
           :exc:`~zhmcclient.ConnectionError`
         """
         resource_obj_list = []
-        query_parms, client_filters = self._divide_filter_args(filter_args)
+        query_parms, client_filters = divide_filter_args(
+            self._query_props, filter_args)
         resources_name = 'user-patterns'
         uri = '{}/{}{}'.format(self.console.uri, resources_name, query_parms)
 
@@ -142,7 +144,7 @@ class UserPatternManager(BaseManager):
                     name=props.get(self._name_prop, None),
                     properties=props)
 
-                if self._matches_filters(resource_obj, client_filters):
+                if matches_filters(resource_obj, client_filters):
                     resource_obj_list.append(resource_obj)
                     if full_properties:
                         resource_obj.pull_full_properties()
@@ -272,13 +274,16 @@ class UserPattern(BaseResource):
         # pylint: disable=protected-access
         self.manager.session.delete(self.uri)
         self.manager._name_uri_cache.delete(
-            self._properties.get(self.manager._name_prop, None))
+            self.get_properties_local(self.manager._name_prop, None))
 
     @logged_api_call
     def update_properties(self, properties):
         """
         Update writeable properties of this UserPattern.
 
+        This method serializes with other methods that access or change
+        properties on the same Python object.
+
         Authorization requirements:
 
         * Task permission to the "Manage User Patterns" task.
@@ -304,7 +309,7 @@ class UserPattern(BaseResource):
         if is_rename:
             # Delete the old name from the cache
             self.manager._name_uri_cache.delete(self.name)
-        self._properties.update(copy.deepcopy(properties))
+        self.update_properties_local(copy.deepcopy(properties))
         if is_rename:
             # Add the new name to the cache
             self.manager._name_uri_cache.update(self.name, self.uri)
