@@ -1,4 +1,4 @@
-# Copyright 2017 IBM Corp. All Rights Reserved.
+# Copyright 2017-2021 IBM Corp. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -31,6 +31,7 @@ import six
 from ._manager import BaseManager
 from ._resource import BaseResource
 from ._logging import logged_api_call
+from ._utils import matches_filters, divide_filter_args
 
 __all__ = ['UserRoleManager', 'UserRole']
 
@@ -121,7 +122,8 @@ class UserRoleManager(BaseManager):
           :exc:`~zhmcclient.ConnectionError`
         """
         resource_obj_list = []
-        query_parms, client_filters = self._divide_filter_args(filter_args)
+        query_parms, client_filters = divide_filter_args(
+            self._query_props, filter_args)
         resources_name = 'user-roles'
         uri = '{}/{}{}'.format(self.console.uri, resources_name, query_parms)
 
@@ -136,7 +138,7 @@ class UserRoleManager(BaseManager):
                     name=props.get(self._name_prop, None),
                     properties=props)
 
-                if self._matches_filters(resource_obj, client_filters):
+                if matches_filters(resource_obj, client_filters):
                     resource_obj_list.append(resource_obj)
                     if full_properties:
                         resource_obj.pull_full_properties()
@@ -236,7 +238,7 @@ class UserRole(BaseResource):
         # pylint: disable=protected-access
         self.manager.session.delete(self.uri)
         self.manager._name_uri_cache.delete(
-            self._properties.get(self.manager._name_prop, None))
+            self.get_properties_local(self.manager._name_prop, None))
 
     @logged_api_call
     def update_properties(self, properties):
@@ -246,6 +248,9 @@ class UserRole(BaseResource):
         The User Role must be user-defined. System-defined User Roles cannot be
         updated.
 
+        This method serializes with other methods that access or change
+        properties on the same Python object.
+
         Authorization requirements:
 
         * Task permission to the "Manage User Roles" task.
@@ -272,7 +277,7 @@ class UserRole(BaseResource):
         # cause HTTPError to be raised in the POST above, so we assert that
         # here, because we omit the extra code for handling name updates:
         assert self.manager._name_prop not in properties
-        self._properties.update(copy.deepcopy(properties))
+        self.update_properties_local(copy.deepcopy(properties))
 
     @logged_api_call
     def add_permission(self, permitted_object, include_members=False,
