@@ -1,4 +1,4 @@
-# Copyright 2016-2017 IBM Corp. All Rights Reserved.
+# Copyright 2016-2021 IBM Corp. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -71,6 +71,8 @@ class FakedSession(zhmcclient.Session):
         super(FakedSession, self).__init__(host)
         self._hmc = FakedHmc(hmc_name, hmc_version, api_version)
         self._urihandler = UriHandler(URIS)
+        self._object_topic = 'faked-notification-topic'
+        self._job_topic = 'faked-job-notification-topic'
 
     def __repr__(self):
         """
